@@ -2,33 +2,33 @@
 
 use anyhow::Result;
 use std::iter::Peekable;
-use syntree::{print, Tree, TreeBuilder, TreeBuilderError};
+use syntree::{print, Tree, TreeBuilder, TreeError};
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 #[allow(non_camel_case_types)]
-enum SyntaxKind {
-    WHITESPACE = 0,
-
+enum Syntax {
     ADD,
     SUB,
     MUL,
     DIV,
 
+    WHITESPACE,
+
     NUMBER,
     ERROR,
     OPERATION,
     ROOT,
 }
 
-use SyntaxKind::*;
+use Syntax::*;
 
-struct Parser<I: Iterator<Item = (SyntaxKind, usize)>> {
-    builder: TreeBuilder<SyntaxKind>,
+struct Parser<I: Iterator<Item = (Syntax, usize)>> {
+    builder: TreeBuilder<Syntax>,
     iter: Peekable<I>,
 }
 
-impl<I: Iterator<Item = (SyntaxKind, usize)>> Parser<I> {
-    fn peek(&mut self) -> Option<SyntaxKind> {
+impl<I: Iterator<Item = (Syntax, usize)>> Parser<I> {
+    fn peek(&mut self) -> Option<Syntax> {
         while self
             .iter
             .peek()
@@ -46,7 +46,7 @@ impl<I: Iterator<Item = (SyntaxKind, usize)>> Parser<I> {
         }
     }
 
-    fn parse_val(&mut self) -> Result<(), TreeBuilderError> {
+    fn parse_val(&mut self) -> Result<(), TreeError> {
         match self.peek() {
             Some(NUMBER) => self.bump(),
             _ => {
@@ -61,9 +61,9 @@ impl<I: Iterator<Item = (SyntaxKind, usize)>> Parser<I> {
 
     fn handle_operation(
         &mut self,
-        tokens: &[SyntaxKind],
-        next: fn(&mut Self) -> Result<(), TreeBuilderError>,
-    ) -> Result<(), TreeBuilderError> {
+        tokens: &[Syntax],
+        next: fn(&mut Self) -> Result<(), TreeError>,
+    ) -> Result<(), TreeError> {
         let c = self.builder.checkpoint();
         next(self)?;
 
@@ -76,15 +76,15 @@ impl<I: Iterator<Item = (SyntaxKind, usize)>> Parser<I> {
         Ok(())
     }
 
-    fn parse_mul(&mut self) -> Result<(), TreeBuilderError> {
+    fn parse_mul(&mut self) -> Result<(), TreeError> {
         self.handle_operation(&[MUL, DIV], Self::parse_val)
     }
 
-    fn parse_add(&mut self) -> Result<(), TreeBuilderError> {
+    fn parse_add(&mut self) -> Result<(), TreeError> {
         self.handle_operation(&[ADD, SUB], Self::parse_mul)
     }
 
-    fn parse(mut self) -> Result<Tree<SyntaxKind>, TreeBuilderError> {
+    fn parse(mut self) -> Result<Tree<Syntax>, TreeError> {
         self.builder.open(ROOT);
         self.parse_add()?;
         self.builder.close()?;
@@ -92,7 +92,7 @@ impl<I: Iterator<Item = (SyntaxKind, usize)>> Parser<I> {
     }
 }
 
-fn lexer(source: &str) -> impl Iterator<Item = (SyntaxKind, usize)> + '_ {
+fn lexer(source: &str) -> impl Iterator<Item = (Syntax, usize)> + '_ {
     let mut it = source.char_indices().peekable();
     let len = source.len();
 
